/***************************************************************************
 *   Copyright (C) 2005-2006 Nicolas Hadacek <hadacek@kde.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "common/global/pfile.h"

#include <qfile.h>

//-----------------------------------------------------------------------------
bool PURL::File::openForWrite()
{
  close();
  _file->setName(url().filepath());
  if (!_file->open(IO_WriteOnly)) {
    _error = i18n("Could not open file for writing.");
    _log.sorry(_error, i18n("File: %1").arg(_file->name()));
    return false;
  }
  return true;
}

bool PURL::File::close()
{
  _file->close();
  return ( uint(_file->status())==IO_Ok );
}

bool PURL::File::openForRead()
{
  close();
  _file->setName(_url.filepath());
  if ( !_file->open(IO_ReadOnly) ) {
    _error = i18n("Could not open file for reading.");
    _log.sorry(_error, i18n("File: %1").arg(_file->name()));
    return false;
  }
  return true;
}

bool PURL::File::remove()
{
  return _file->remove();
}

//-----------------------------------------------------------------------------
PURL::TempFile::TempFile(Log::Generic &log, const QString &extension)
  : FileBase(log, extension)
{}

PURL::Url PURL::TempFile::url() const
{
  return (_tmp.get() != NULL ? fromPathOrUrl(_tmp->name(), false) : Url());
}

bool PURL::TempFile::close()
{
  _stream.reset(NULL);
  if (_tmp.get() != NULL) {
    _tmp->close();
    if ( _tmp->status()!=IO_Ok ) {
      _error = i18n("Could not write to temporary file.");
      _log.sorry(_error, i18n("File: %1").arg(_tmp->name()));
      return false;
    }
  }
  return true;
}

bool PURL::TempFile::openForWrite()
{
  close();
  _tmp.reset(new KTempFile(QString::null, _extension));
  _tmp->setAutoDelete(true);
  if ( _tmp->status()!=0 ) {
    _error = i18n("Could not create temporary file.");
    _log.sorry(_error, i18n("File: %1").arg(_tmp->name()));
    return false;
  }
  return true;
}
